bbprep.TargetProcess
====================

.. currentmodule:: bbprep

.. autoclass:: TargetProcess
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetProcess.calculate_score
      ~TargetProcess.calculate_value
      ~TargetProcess.get_all_scores
      ~TargetProcess.get_best
      ~TargetProcess.get_best_id
   
   

   
   
   